package edu.fudan.ss.ooad.eclipse.views;

import java.util.ArrayList;
import java.util.Collection;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IExtension;
import org.eclipse.core.runtime.InvalidRegistryObjectException;
import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.viewers.LabelProvider;

import edu.fudan.ss.ooad.eclipse.core.ICourse;
import edu.fudan.ss.ooad.eclipse.core.INamedElement;

public class CourseLabelProvider extends LabelProvider {
	@Override
	public String getText(Object element) {
		String name = ((INamedElement) element).getName();

		// If course is to be displayed, we use extension to
		// decorate the initial result
		if (element instanceof ICourse) {
			for (ICourseDecorator decorator : getCourseDecorators()) {
				name = decorator.decorate(name);
			}
		}

		return name;
	}

	private Collection<ICourseDecorator> getCourseDecorators() {
		Collection<ICourseDecorator> results = new ArrayList<ICourseDecorator>();
		IExtension[] extensions = Platform
				.getExtensionRegistry()
				.getExtensionPoint(
						"edu.fudan.ss.ooad.eclipse.course.decorators")
				.getExtensions();
		for (IExtension extension : extensions) {
			ICourseDecorator decorator;
			try {
				decorator = (ICourseDecorator) extension
						.getConfigurationElements()[0]
						.createExecutableExtension("class");
				results.add(decorator);
			} catch (InvalidRegistryObjectException e) {
				// TODO Log Error and continue
			} catch (CoreException e) {
				// TODO Log Error and continue
			}

		}
		return results;
	}
}
